-- Body of water
CREATE TABLE BodyOfWater (
    Name TEXT PRIMARY KEY
);

-- Single sensor
CREATE TABLE Sensor (
    SensorID INT PRIMARY KEY,
    SensorType TEXT CHECK(SensorType IN ('LiDar', 'Magnetic', 'Other')),
    Active BOOLEAN
);

-- Measurement taken at a given time
CREATE TABLE Measurement (
    MeasurementID INT PRIMARY KEY,
    SensorID INT NOT NULL,
    TimeMeasured DATETIME NOT NULL,
    WaterBodyName TEXT NOT NULL,
    WholeAverageThickness FLOAT NOT NULL,
    FOREIGN KEY (SensorID) REFERENCES Sensor(SensorID),
    FOREIGN KEY (WaterBodyName) REFERENCES BodyOfWater(Name)
);

CREATE TABLE SubDivision (
    MeasurementID INT,
    SubDivisionID INT,
    GroupID INT NOT NULL,
    MinimumThickness FLOAT NOT NULL,
    AverageThickness FLOAT NOT NULL,
    CenterLatitude FLOAT NOT NULL,
    CenterLongitude FLOAT NOT NULL,
    Accuracy FLOAT,
    FOREIGN KEY (MeasurementID) REFERENCES Measurement(MeasurementID),
    PRIMARY KEY (MeasurementID, SubDivisionID)
);

-- Indexes
CREATE INDEX idx_measurement_waterbodyname ON Measurement(WaterBodyName);
CREATE INDEX idx_measurement_timemeasured ON Measurement(TimeMeasured);

-- Test data
INSERT INTO Sensor (SensorID, SensorType, Active) VALUES
(1, 'LiDar', 1),
(2, 'Magnetic', 1),
(3, 'Other', 0);

INSERT INTO BodyOfWater(Name) VALUES
('Mjosa');

INSERT INTO Measurement (MeasurementID, SensorID, TimeMeasured, WaterBodyName, WholeAverageThickness) VALUES
(1, 2, '2024-01-01 10:00:00', 'Mjosa', 5.8),
(2, 2, '2024-02-04 11:00:00', 'Mjosa', 7.6),
(3, 1, '2024-02-13 12:00:00', 'Mjosa', 4.1);

INSERT INTO SubDivision (MeasurementID, SubDivisionID, GroupID, MinimumThickness, AverageThickness, CenterLatitude, CenterLongitude, Accuracy)  VALUES
(1, 1, 1, 3.2, 4.5, 60.765, 10.723, 1.2),
(1, 2, 1, 2.8, 4.3, 60.780, 10.776, 1.1),
(1, 3, 2, 4.1, 5.7, 60.768, 10.845, 1.3),
(1, 4, 2, 3.5, 5.0, 60.749, 10.783, 1.4),
(2, 1, 1, 4.1, 5.7, 60.768, 10.845, 1.3),
(2, 2, 2, 3.5, 5.0, 60.749, 10.783, 1.4),
(3, 1, 1, 4.1, 5.7, 60.768, 10.845, 1.3),
(3, 2, 2, 3.5, 5.0, 60.749, 10.783, 1.4);



